<?php
/**
 *  WASP Admin Settings Class
 *
 * @since 1.0
 * @debug
 */

class WASPsettingsPage
{
 /**
  * Holds the values to be used in the fields callbacks
  */
 private $options;

 /**
  * Start up
  */
 public function __construct()
 {
     add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
     add_action( 'admin_init', array( $this, 'page_init' ) );
     // Footer Hook
     add_action('admin_head',  array( $this, 'wasp_admin_footer' ) );
}

 /**
  * Add options page
  */
 public function add_plugin_page()
 {
     add_submenu_page(
     'woocommerce',
     'AI Suggested Products',
     'AI Suggested Products',
     'manage_options',
     'wasp-suggested-products',
     array( $this, 'create_admin_page')
   );
 }


 /**
  * Options page callback
  */
 public function create_admin_page()
 {
   // Wipe Options
   //delete_option( 'wasp_option' );

   // Load defult setting if not set
   if (empty(get_option( 'wasp_option' ))) {
     $default_options =[
        'wasp_location_single_product' => 'top',
        'wasp_enable_cart' => 1,
        'wasp_location_cart' => 'bottom',
        'wasp_location_checkout' => 'top',
        'wasp_how_many_items_general' => 4,
        'wasp_enable_title' => 1,
        'wasp_location_title' => 'top',
        'wasp_title_color' => '#000000',
        'wasp_title_size' => 20,
        'wasp_enable_price' => 1,
        'wasp_location_price' => 'bottom',
        'wasp_price_color' => '#000000',
        'wasp_price_size' => 16
     ];
     update_option( 'wasp_option', $default_options );
   }
   //qwebmaster_print_array(get_option( 'wasp_option' ));
     // Set class property
     $this->options = get_option( 'wasp_option' );
     ?>
     <div class="wasp_settings_wrapper">
         <h1>Woocommerce AI Suggested Products Settings</h1>
         <form method="post" action="options.php">
         <?php
             // This prints out all hidden setting fields
             settings_fields( 'wasp_option_group' );
             do_settings_sections( 'wasp-suggested-products' );
             submit_button();
         ?>
         </form>
     </div>
     <?php
 }


 /**
  * Register and add settings
  */
 public function page_init()
 {

     register_setting(
         'wasp_option_group', // Option group
         'wasp_option', // Option name
         array( $this, 'sanitize' ) // Sanitize
     );


     //
     // How It Works Section
     //
     add_settings_section(
         'wasp_general_how_it_works', // ID
         '', // Title
         array( $this, 'print_section_how_it_works' ), // Callback
         'wasp-suggested-products' // Page
     );


     //
     // General Settings Section
     //
     add_settings_section(
         'wasp_general_setting_section', // ID
         'General Settings', // Title
       array( $this, 'wasp_print_section_blank' ), // Callback
         'wasp-suggested-products' // Page
     );

     add_settings_field(
        'wasp_single_product_page', // ID
        'Single Product Page', // Title
        array( $this, 'general_section_single_product_page_callback' ), // Callback
        'wasp-suggested-products', // Page
        'wasp_general_setting_section' // Section
     );

     add_settings_field(
        'wasp_cart_page', // ID
        'Cart Page', // Title
        array( $this, 'general_section_cart_page_callback' ), // Callback
        'wasp-suggested-products', // Page
        'wasp_general_setting_section' // Section
     );

     add_settings_field(
        'wasp_checkout_page', // ID
        'Checkout Page', // Title
        array( $this, 'general_section_checkout_page_callback' ), // Callback
        'wasp-suggested-products', // Page
        'wasp_general_setting_section' // Section
     );

     add_settings_field(
         'wasp_general_how_many_items', // ID
         'How many products to display', // Title
         array( $this, 'wasp_how_many_items_general_callback' ), // Callback
         'wasp-suggested-products', // Page
         'wasp_general_setting_section' // Section
     );

     //
     // Style Section
     //
     add_settings_section(
         'wasp_style_setting_section', // ID
         'Style Settings', // Title
       array( $this, 'wasp_print_section_blank' ), // Callback
         'wasp-suggested-products' // Page
     );

     add_settings_field(
        'wasp_style_setting_title', // ID
        'Product Title', // Title
        array( $this, 'wasp_title_callback' ), // Callback
        'wasp-suggested-products', // Page
        'wasp_style_setting_section' // Section
     );
     add_settings_field(
        'wasp_style_setting_price', // ID
        'Product Price', // Title
        array( $this, 'wasp_price_callback' ), // Callback
        'wasp-suggested-products', // Page
        'wasp_style_setting_section' // Section
     );

 }



 /**
  * Sanitize each setting field as needed
  *
  * @param array $input Contains all settings fields as array keys
  */
 public function sanitize( $input )
 {
      /*
      if( isset( $input['renewal_days'] ) )
      $new_input['renewal_days'] = absint( $input['renewal_days'] );

      if( isset( $input['wasp_location_single_product'] ) )
      $new_input['wasp_location_single_product'] = sanitize_text_field( $input['wasp_location_single_product'] );
      */
     //return $new_input;
     return $input;
 }




 /**
  * Section title
  */
 public function qwebmaster_wasp_general_settings_title($title)
 {
        //echo '<h2>General Settings</h2>';
 }


 /**
  * Blank
  */
 public function wasp_print_section_blank()
 {

 }



 /**
  *
  *  How It Works Callbacks
  *
  */

 /**
  * How it Works
  */
 public function print_section_how_it_works()
 {
     //print 'Enter your settings below:';
echo '<div class="wasp_how_it_works">';
echo '<h2>How It Works</h2>';
echo '<div class ="wasp_padding_20">';
echo '<p>This plugin will scan all your existing orders and create associacions for what products are likley to be purchased based on apst orders.<p>';
echo '<p>You have: '.qwebmaster_ai_woocommerce_total_order_count().' Orders<p>';
echo '</div>';
echo '</div>';
echo '
 <style>
 </style>
     ';
 }



 /**
  *
  *  General Settings Callbacks
  *
  */

 /**
  * Single product Page
  */
 public function general_section_single_product_page_callback( $options = '', $option = '')
 {
  echo '<div class="wasp_sub_section">';
   print(
       '<input type="checkbox" id="wasp_enable_single_product" name="wasp_option[wasp_enable_single_product]" value="1" '.checked( 1, isset($this->options['wasp_enable_single_product']), false ).'/>'
     );
     print(
        '<label for="checkbox_element"> Enable </label>'
      );

        if (isset($this->options['wasp_location_single_product'])) {
          $options = $this->options['wasp_location_single_product'];
          $option = $options;
        }

        // Generate Dropdown
        $options = array(
          array(
            'text' => 'Top',
            'id' => 'top',
            'selected' => selected($option, 'top' )
          ),
          array(
            'text' => 'Bottom',
            'id' => 'bottom',
            'selected' => selected($option, 'bottom' )
          )
        );
      $this->wasp_settings_generate_dropdown($options, 'wasp_location_single_product', 'Select Position');

     echo '</div>';


 }


 /**
  * cart Page
  */
 public function general_section_cart_page_callback( $options = '', $option = '')
 {
  echo '<div class="wasp_sub_section">';
   print(
       '<input type="checkbox" id="wasp_enable_cart" name="wasp_option[wasp_enable_cart]" value="1" '.checked( 1, isset($this->options['wasp_enable_cart']), false ).'/>'
     );
     print(
        '<label for="checkbox_element"> Enable </label>'
      );

        if (isset($this->options['wasp_location_cart'])) {
          $options = $this->options['wasp_location_cart'];
          $option = $options;
        }

        // Generate Dropdown
        $options = array(
          array(
            'text' => 'Top',
            'id' => 'top',
            'selected' => $option
          ),
          array(
            'text' => 'Bottom',
            'id' => 'bottom',
            'selected' => $option
          )
        );
      $this->wasp_settings_generate_dropdown($options, 'wasp_location_cart', 'Select Position');
     echo '</div>';
 }

 /**
  * Checkout Page
  */
 public function general_section_checkout_page_callback( $options = '', $option = '')
 {
  echo '<div class="wasp_sub_section">';
   print(
       '<input type="checkbox" id="wasp_enable_checkout" name="wasp_option[wasp_enable_checkout]" value="1" '.checked( 1, isset($this->options['wasp_enable_checkout']), false ).'/>'
     );
     print(
        '<label for="checkbox_element"> Enable </label>'
      );

        if (isset($this->options['wasp_location_checkout'])) {
          $options = $this->options['wasp_location_checkout'];
          $option = $options;
        }

//qwebmaster_print_array($this->options);
        // Generate Dropdown
        $options = array(
          array(
            'text' => 'Top',
            'id' => 'top',
            'selected' => $option
          ),
          array(
            'text' => 'Bottom',
            'id' => 'bottom',
            'selected' => $option
          )
        );
      $this->wasp_settings_generate_dropdown($options, 'wasp_location_checkout', 'Select Position');
     echo '</div>';
 }

 /**
  * Get the settings option array and print one of its values
  */
 public function wasp_how_many_items_general_callback()
 {
 //$this->options ='';
     printf(
         '<input type="text" id="wasp_how_many_items_general" name="wasp_option[wasp_how_many_items_general]" value="%s" />
          <p class="description">Set the related item limit. Default:4 Sometimes more than one related products are found by the AI.</p>
         ',
         isset( $this->options['wasp_how_many_items_general'])  ? esc_attr( $this->options['wasp_how_many_items_general']) : ''
     );
 }



/**
 *
 *  Style Page Settings Callbacks
 *
 */

/**
 * Style title
 */
 public function wasp_title_callback($options = '', $option = '') {

     echo '<div class="wasp_sub_section">';

     print(
         '<input type="checkbox" id="wasp_enable_title" name="wasp_option[wasp_enable_title]" value="1" '.checked( 1, isset($this->options['wasp_enable_title']), false ).'/>'
       );
       print(
          '<label for="wasp_option[wasp_enable_title]"> Enable </label>'
        );

     if (isset($this->options['wasp_location_title'])) {
       $options = $this->options['wasp_location_title'];
       $option = $options;
     }

     $options = array(
       array(
         'text' => 'Top',
         'id' => 'top',
         'selected' => $option
       ),
       array(
         'text' => 'Bottom',
         'id' => 'bottom',
         'selected' => $option
       )
     );
    $this->wasp_settings_generate_dropdown($options, 'wasp_location_title', 'Select Position');

     echo '<div class="wasp_input_wrap">';
     $title_color = ( isset( $this->options['wasp_title_color'] ) ) ? $this->options['wasp_title_color'] : '';
     echo '<input type="text" name="wasp_option[wasp_title_color]" value="' . $title_color . '" class="wasp-color-picker" >';
     print(
        '<label for="checkbox_element">Title Color </label>'
      );
     echo '</div>';

    echo '<div class="wasp_input_wrap">';
    $title_size = ( isset( $this->options['wasp_title_size'] ) ) ? $this->options['wasp_title_size'] : '';
    echo '<input type="number" name="wasp_option[wasp_title_size]" value="' . $title_size . '" class="" >';
    print(
       '<label for="checkbox_element"> Title Font Size in px. Default:14 </label>'
     );
    echo '</div>';
    echo '</div>';
 }


 /**
  * Style Price
  */
  public function wasp_price_callback($options = '', $option = '') {

      echo '<div class="wasp_sub_section">';

      print(
          '<input type="checkbox" id="wasp_enable_price" name="wasp_option[wasp_enable_price]" value="1" '.checked( 1, isset($this->options['wasp_enable_price']), false ).'/>'
        );
        print(
           '<label for="wasp_option[wasp_enable_price]"> Enable </label>'
         );

      if (isset($this->options['wasp_location_price'])) {
        $options = $this->options['wasp_location_price'];
        $option = $options;
      }

      $options = array(
        array(
          'text' => 'Top',
          'id' => 'top',
          'selected' => $option
        ),
        array(
          'text' => 'Bottom',
          'id' => 'bottom',
          'selected' => $option
        )
      );
     $this->wasp_settings_generate_dropdown($options, 'wasp_location_price', 'Select Position');

      echo '<div class="wasp_input_wrap">';
      $price_color = ( isset( $this->options['wasp_price_color'] ) ) ? $this->options['wasp_price_color'] : '';
      echo '<input type="text" name="wasp_option[wasp_price_color]" value="' . $price_color . '" class="wasp-color-picker" >';
      print(
         '<label for="checkbox_element">price Color </label>'
       );
      echo '</div>';

     echo '<div class="wasp_input_wrap">';
     $price_size = ( isset( $this->options['wasp_price_size'] ) ) ? $this->options['wasp_price_size'] : '';
     echo '<input type="number" name="wasp_option[wasp_price_size]" value="' . $price_size . '" class="" >';
     print(
        '<label for="checkbox_element"> price Font Size in px. Default:14 </label>'
      );
     echo '</div>';
     echo '</div>';
  }




 /**
  * Generate dropdown HTML
  *
  * Helper function
  */
 public function wasp_settings_generate_dropdown($options,$name,$title) {
 ?>
 <div class='wasp_option_wrap'>
 <p><?php echo $title ?></p>
 <select name="wasp_option[<?php echo $name ?>]" onchange="">
 <?php
 foreach($options as $option): ?>
     <option value="<?php echo $option['id'];?>" <?php echo selected($option['selected'], $option['id'] ) ?>><?php echo $option['text']; ?></option>
 <?php endforeach ?>
 </select>
 </div>
 <?php
 }




 /**
  * Load Admin Styles and JS
  */
 public function wasp_admin_footer() {
   global $hook_suffix;
   // Only load on plugin settings page
   if ($hook_suffix == 'woocommerce_page_wasp-suggested-products') {
   ?>
    <style>
        .wasp_settings_wrapper {
          padding-right: 20px;
        }
        #wpcontent {
          margin-left: 140px;
        }
        #wpbody {
          /* background-color: #ffffff; */
          padding-left: 20px;
        }
        .wasp_how_it_works {
         padding: 0px;
         background: #fff;
         margin: 30px 0px;
       }
       .wasp_settings_wrapper h2 {
         width: auto;
         padding: 16px;
         background: #2196f3;
         color: #ffffff;
         text-transform: uppercase;
       }

       .wasp_option_wrap, .wasp_input_wrap {
         margin-top: 20px;
       }

       .wasp_option_wrap p {
         font-weight: bold;
       }

       .wasp_sub_section {
         padding: 20px;
         background: #ffffff;
       }

       .wasp_padding_20 {
         padding: 20px;
       }

    </style>
  <script>
  (function( $ ) {
    $(function() {

        // Add Color Picker to all inputs that have 'color-field' class
        $( '.wasp-color-picker' ).wpColorPicker();

    });
  })( jQuery );
  </script>
   <?php
   } // Only load on plugin settings page
 }


}

if( is_admin() )
 $wsrr_settings_page = new WASPsettingsPage();
